#include "BuildLibrary.h"

#include "Logger.h"
#include "Directory.h"

BuildLibrary::BuildLibrary(const FileSystemPath& build_config)
    : m_build_config(build_config)
{
}

Status BuildLibrary::scan()
{
    LOG_INFO("Scanning build file at: " << m_build_config);
    const auto search_dir = m_build_config.parent_path();
    m_name = search_dir.stem().str();

    STATUS_CHECK(Directory::getFilesWithExtension(search_dir, 
        ".cpp", 
        m_sources, 
        true), "Error collecting source files")

    m_include_dirs.push_back(search_dir);

    STATUS_CHECK(Directory::getAllSubDirectories(search_dir, 
        m_include_dirs), "Error collecting include dirs")
    return {};
}

const String& BuildLibrary::get_name() const 
{
    return m_name;
}

const Vector<FileSystemPath>& BuildLibrary::get_sources() const 
{
    return m_sources;
}

const Vector<FileSystemPath>& BuildLibrary::get_include_dirs() const 
{
    return m_include_dirs;
}